@@ -5,7 +5,7 @@ import presalytics.lib.exceptions
 
 site_host = "https://presalytics.io"
 try:
-    site_host = presalytics.CONFIG["HOSTS"]["SITE"] #type: ignore
+    site_host = presalytics.CONFIG.get("BROWSER_API_HOST", {}).get('SITE', "https://presalytics.io") #type: ignore
 except (KeyError, AttributeError, ImportError, ModuleNotFoundError):
     pass
 
@@ -54,6 +54,7 @@ class ApprovedExternalLinks(presalytics.lib.plugins.base.StylePlugin):
     __plugin_name__ = 'external_links'
 
     STYLES_MAP = {
+        'c3': '{0}/static/vendor/c3/c3.min.css'.format(site_host),
         'reveal': {
             'base': '{0}/static/vendor/reveal/reveal.css'.format(site_host),
             'themes': {
@@ -75,6 +76,9 @@ class ApprovedExternalLinks(presalytics.lib.plugins.base.StylePlugin):
         'preloaders' : '{0}/static/css/preloaders.css'.format(site_host),
         'bootstrap4': "https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/css/bootstrap.min.css",
         'font-awesome': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.14.0/css/all.min.css',
+        'bootstrap-table': 'https://unpkg.com/bootstrap-table@1.18.0/dist/bootstrap-table.min.css',
+        'markdown-css': 'https://cdnjs.cloudflare.com/ajax/libs/github-markdown-css/4.0.0/github-markdown.min.css'
+    
     }
     """
     Static nested dictionary containing links to external stylesheets that will be rendered alongside this plugin
@@ -113,6 +117,7 @@ class ApprovedExternalScripts(presalytics.lib.plugins.base.ScriptPlugin):
     __plugin_name__ = 'external_scripts'
 
     SCRIPT_MAP = {
+        'c3': '{0}/static/vendor/c3/c3.min.js'.format(site_host),
         'd3': 'https://d3js.org/d3.v5.min.js',
         'd3v3': 'https://cdnjs.cloudflare.com/ajax/libs/d3/3.5.17/d3.min.js',
         'reveal': {
@@ -128,11 +133,12 @@ class ApprovedExternalScripts(presalytics.lib.plugins.base.ScriptPlugin):
 
         },
         'mpld3': '{0}/static/mpld3/mpld3.min.js'.format(site_host),
-        'ooxml': '{0}/static/ooxml/ooxml.js'.format(site_host),
+        'ooxml': '{0}/static/js/ooxml.js'.format(site_host),
         'mpl-responsive': '{0}/static/js/mpl-responsive.js'.format(site_host),
         'jquery': 'https://code.jquery.com/jquery-3.4.1.min.js',
         'popper': 'https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.3/umd/popper.min.js',
-        'bootstrap4': 'https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/js/bootstrap.min.js'
+        'bootstrap4': 'https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/js/bootstrap.min.js',
+        'bootstrap-table': 'https://unpkg.com/bootstrap-table@1.18.0/dist/bootstrap-table.min.js'
     }
     """
     Static nested dictionary containing links to external scripts that will be rendered alongside this plugin
